apiculture/default_key
Values
pub fn generate() -> Result(key.Key, error.Error)
Generate a default format key without a prefix.
This produces a key in the format: <base62-random><checksum>
pub fn prefixed(prefix: String) -> Result(key.Key, error.Error)
Generate a default format key with the given prefix.
This produces a key in the format: <prefix>_<base62-random><checksum>
The prefix should be a short semantic identifier (e.g., “sk”, “token”, “key”).